@@ -55,7 +55,7 @@ void AddTreeToModel(vector<Example>& examples, Model* model, char loss_type, flo
   }
   InitializeTreeData(examples, normalizer);
   int best_old_tree_idx = -1;
-  float best_wgtd_error, wgtd_error, gradient, best_gradient = 0;
+  float wgtd_error, gradient, best_wgtd_error = 0, best_gradient = 0;
 
   // Find best old tree
   bool old_tree_is_best = false;
@@ -85,7 +85,7 @@ void AddTreeToModel(vector<Example>& examples, Model* model, char loss_type, flo
   }
 
   // Update model weights
-  float alpha;
+  float alpha = 0;
   const Tree* tree;
   if (old_tree_is_best) {
     alpha = (*model)[best_old_tree_idx].first;
@@ -107,7 +107,7 @@ void AddTreeToModel(vector<Example>& examples, Model* model, char loss_type, flo
   for (Example& example : examples) {
     const float u = eta * example.label * ClassifyExample(example, *tree);
     if (loss_type == 'e') {
-      example.weight *= std::exp(-u);
+      example.weight = example.weight * std::exp(-u) * old_normalizer;
     } else if (loss_type == 'l') {
       const float z = (1 - std::log(2) * example.weight * old_normalizer) /
                       (std::log(2) * example.weight * old_normalizer);
